@@ -8,15 +8,19 @@ httpget_webhook <- function(){
   #make sure it's POST
   res$checkmethod("POST")
   
-  #extract hook payload
-  payload <- req$post()$payload;
-  if(is.null(payload)){
-    stop("No argument 'payload' posted.")
+  #webhook payload can either be pure json or url-encoded
+  if(isTRUE(grepl("application/json", req$ctype()))){
+    payload <- req$post();
+  } else {
+    #extract hook payload
+    payload <- req$post()$payload;
+    if(is.null(payload)){
+      stop("No argument 'payload' posted.")
+    }
+    #convert from JSON
+    payload <- fromJSON(payload);
   }
   
-  #convert from JSON
-  payload <- fromJSON(payload);
-  
   #Post-Receive data
   gitref <- payload$ref;
   giturl <- payload$repository$url;  
